diff --git a/books/bookvol10.1.pamphlet b/books/bookvol10.1.pamphlet
index 803ce2b..ffd6276 100644
--- a/books/bookvol10.1.pamphlet
+++ b/books/bookvol10.1.pamphlet
@@ -7586,6 +7586,760 @@ i =
 \right]
 $$
 
+\chapter{Clifford Algebra\cite{39}}
+
+This is quoted from John Fletcher's web page\cite{39} (with permission).
+
+The theory of Clifford Algebra includes a statement that each Clifford
+Algebra is isomorphic to a matrix representation. Several authors
+discuss this and in particular Ablamowicz\cite{41} gives examples of
+derivation of the matrix representation. A matrix will itself satisfy
+the characteristic polynomial equation obeyed by its own
+eigenvalues. This relationship can be used to calculate the inverse of
+a matrix from powers of the matrix itself. It is demonstrated that the
+matrix basis of a Clifford number can be used to calculate the inverse
+of a Clifford number using the characteristic equation of the matrix
+and powers of the Clifford number. Examples are given for the algebras
+Clifford(2), Clifford(3) and Clifford(2,2).
+
+\section{Introduction}
+
+Introductory texts on Clifford algebra state that for any chosen
+Clifford Algebra there is a matrix representation which is equivalent.
+Several authors discuss this in more detail and in particular,
+Ablamowicz\cite{41} shows that the matrices can be derived for each algebra
+from a choice of idempotent, a member of the algebra which when
+squared gives itself.  The idea of this paper is that any matrix obeys
+the characteristic equation of its own eigenvalues, and that therefore
+the equivalent Clifford number will also obey the same characteristic
+equation.  This relationship can be exploited to calculate the inverse
+of a Clifford number. This result can be used symbolically to find the
+general form of the inverse in a particular algebra, and also in
+numerical work to calculate the inverse of a particular member.  This
+latter approach needs the knowledge of the matrices.  Ablamowicz has
+provided a method for generating them in the form of a Maple
+implementation. This knowledge is not believed to be new, but the
+theory is distributed in the literature and the purpose of this paper
+is to make it clear.  The examples have been first developed using a
+system of symbolic algebra described in another paper by this
+author\cite{40}.  
+
+\section{Clifford Basis Matrix Theory}
+
+The theory of the matrix basis is discussed extensively by
+Ablamowicz.  This theory will be illustrated here following the
+notation of Ablamowicz by reference to Clifford(2) algebra and can
+be applied to other Clifford Algebras. For most Clifford algebras
+there is at least one primitive idempotent, such that it squares to
+itself. For Clifford (2), which has two basis members $e_1$ and $e_2$, one
+such idempotent involves only one of the basis members, $e_1$, i.e.
+
+\[f_1 = f = \frac{1}{2} (1 + e_1)\]
+
+If the idempotent is mutiplied by the other basis function $e_2$, other
+functions can be generated:
+
+\[f_2 = e_2 f = \left(\frac{1}{2}-\frac{1}{2}e_1\right)e_2\]
+
+\[f_3 = f e_2 = \left(\frac{1}{2}+\frac{1}{2}e_1\right)e_2\]
+
+\[f_4 = e_2 f e_2 = \frac{1}{2}-\frac{1}{2}e_1\]
+
+Note that $fe_22f = 0$.  These four functions provide a means of
+representing any member of the space, so that if a general member c is
+given in terms of the basis members of the algebra
+
+\[ c = a_0 + a_1e_1 + a_2e_2 + a_3e_1e_2\]
+
+it can also be represented by a series of terms in the idempotent and
+the other functions.
+
+\[
+\begin{array}{rcl}
+c&=&a_{11}f_1 + a_{21}f_2 + a_{12}f_3 + a_{22}f_4\\
+&&\\
+ &=&\frac{1}{2}a_{11} + \frac{1}{2}a_{11}e_1 + \frac{1}{2}a_{21}e_2
+-\frac{1}{2}a_{21}e_1e_2 +\\
+&&\\
+&&\frac{1}{2}a_{12}e_2 + \frac{1}{2}a_{12}e_1e_2 + \frac{1}{2}a_{22} 
+-\frac{1}{2}a_{22}e_1
+\end{array}
+\]
+
+
+Equating coefficients it is clear that the following equations apply.
+\[
+\begin{array}{rcl}
+a_0 &=& \frac{1}{2}a_{11} + \frac{1}{2}a_{22}\\
+&&\\
+a_1 &=& \frac{1}{2}a_{11} - \frac{1}{2}a_{22}\\
+&&\\
+a_2 &=& \frac{1}{2}a_{12} + \frac{1}{2}a_{21}\\
+&&\\
+a_3 &=& \frac{1}{2}a_{12} - \frac{1}{2}a_{21}
+\end{array}
+\]
+
+The reverse equations can be recovered by multiplying the two forms of
+c by different combinations of the functions $f_1$, $f_2$ and $f_3$. 
+The equation
+
+\[
+\begin{array}{rcl}
+f_1cf_1 &=& f_1(a_{11}f_1 + a_{21}f_2 + a_{12}f_3 + a_{22}f_4)f_1\\
+&&\\
+        &=& f_1(a_0 + a_1e_1 + a_2e_2 + a_3e_1e_2)f_1
+\end{array}
+\]
+
+reduces to the equation
+
+\[a_{11}f = (a_0 + a_1)f\]
+
+and similar equations can be deduced from other combinations of the
+functions as follows.
+
+\[
+\begin{array}{rcl}
+f_1cf_2 : a_{12}f &=& (a_2 + a_3)f\\
+&&\\
+f_2cf_1 : a_{21}f &=& (a_2 - a_3)f\\
+&&\\
+f_3cf_2 : a_{22}f &=& (a_0 - a_1)f
+\end{array}
+\]
+
+If a matrix is defined as
+
+\[
+A = \left(
+\begin{array}{cc}
+a_{11} & a_{12} \\
+a_{21} & a_{22}
+\end{array}
+\right)
+\]
+
+so that
+
+\[
+Af = \left(
+\begin{array}{cc}
+a_{11}f & a_{12}f \\
+a_{21}f & a_{22}f
+\end{array}
+\right) 
+=
+\left(
+\begin{array}{cc}
+a_0+a_1 & a_2+a_3 \\
+a_2-a_3 & a_0-a_1
+\end{array}
+\right) f
+\]
+
+then the expression
+
+\[
+\left(
+\begin{array}{cc}
+1 & e_2
+\end{array}
+\right)
+\left(
+\begin{array}{cc}
+a_{11}f & a_{12}f \\
+a_{21}f & a_{22}f
+\end{array}
+\right)
+\left(
+\begin{array}{c}
+1\\
+e_2
+\end{array}
+\right)
+=
+a_{11}f_1 + a_{21}f_2 + a_{12}f_3 + a_{22}f_4 = c
+\]
+
+generates the general Clifford object c.  All that remains to form the
+basis matrices is to make c each basis member in turn, and named as
+shown.
+
+\[
+\begin{array}{lrclcr}
+c=1: & Af & = & 
+\left(
+\begin{array}{cc}
+f & 0\\
+0 & f
+\end{array}
+\right)
+& = & E_0f\\
+c=e_1 & Af & = &
+\left(
+\begin{array}{cc}
+f & 0\\
+0 & -f
+\end{array}
+\right)
+& = & E_1f\\
+c=e_2 & Af & = &
+\left(
+\begin{array}{cc}
+0 & f\\
+f & 0
+\end{array}
+\right)
+& = & E_2f\\
+c=e_1e_2 & Af & = &
+\left(
+\begin{array}{cc}
+0 & f\\
+-f & 0
+\end{array}
+\right)
+& = & E_{12}f
+\end{array}
+\]
+
+These are the usual basis matrices for Clifford (2) except that they
+are multiplied by the idempotent.
+
+This approach provides an explanation for the basis matrices in terms
+only of the Clifford Algebra itself.  They are the matrix
+representation of the basis objects of the algebra in terms of an
+idempotent and an associated vector of basis functions.  This has been
+shown for Clifford (2) and it can be extended to other algebras once
+the idempotent and the vector of basis functions have been identified.
+This has been done in many cases by Ablamowicz.  This will now be
+developed to show how the inverse of a Clifford number can be obtained
+from the matrix representation.  
+
+\section{Calculation of the inverse of a Clifford number}
+
+The matrix basis demonstrated above can be used to calculate the
+inverse of a Clifford number.  In simple cases this can be used to
+obtain an algebraic formulation.  For other cases the algebra is too
+complex to be clear, but the method can still be used to obtain the
+numerical value of the inverse.  To apply the method it is necessary
+to know a basis matrix representation of the algebra being used.
+
+The idea of the method is that the matrix representation will have a
+characteristic polynomial obeyed by the eigenvalues of the matrix and
+also by the matrix itself.  There may also be a minimal polynomial
+which is a factor of the characteristic polynomial, which will have
+also be satisfied by the matrix.  It is clear from the proceding
+section that if $A$ is a matrix representation of $c$ in a Clifford
+Algebra then if some function $f(A) = 0$ then the corresponding Clifford
+function $f(c) = 0$ must also be zero.  In particular if $f(A) = 0$ is the
+characteristic or minimal polynomial of $A$, then $f(c) = 0$ implies that
+$c$ also satisfies the same polynomial.  Then if the inverse of the
+Clifford number, $c^{-1}$ is to be found, then 
+
+\[c^{-1}f(c)=0\]
+
+provides a relationship for $c^{-1}$ in terms of multiples a small number
+of low powers of $c$, with the maximum power one less than the order of
+the polynomial. The method suceeds unless the constant term in the
+polynomial is zero, which means that the inverse does not exist.  For
+cases where the basis matrices are of order two, the inverse will be
+shown to be a linear function of $c$.
+
+The method can be summed up as follows.
+\begin{enumerate}
+\item Find the matrix basis of the Clifford algebra.
+\item Find the matrix representation of the Clifford number whose
+inverse is required.
+\item Compute the characteristic or minimal polynomial.
+\item Check for the existence of the inverse.
+\item Compute the inverse using the coefficients from the polynomial.
+\end{enumerate}
+
+Step 1 need only be done once for any Clifford algebra, and this can
+be done using the method in the previous section, where needed.
+
+Step 2 is trivially a matter of accumulation of the correct multiples
+of the matrices.
+
+Step 3 may involve the use of a computer algebra system to find the
+coefficients of the polynomial, if the matrix size is at all large.
+
+Steps 4 and 5 are then easy once the coefficients are known.
+
+The method will now be demonstrated using some examples.
+
+\subsection{Example 1: Clifford (2)}
+
+In this case the matrix basis for a member of the Clifford algebra
+
+\[c = a_0 + a_1e_1 + a_2e_2 + a_3e_1e_2\]
+
+was developed in the previous section as
+
+\[A=\left(
+\begin{array}{cc}
+a_0+a_1 & a_2+a_3\\
+a_2-a_3 & a_0-a_1
+\end{array}
+\right)\]
+
+This matrix has the characteristic polynomial
+
+\[X^2 - 2Xa_0 + a^2_0 - a^2_1 - a^2_2 + a^2_3 = 0\]
+
+and therefore
+
+\[X^{-1}(X^2 - 2Xa_0 + a^2_0 - a^2_1 - a^2_2 + a^2_3) = 0\]
+
+and
+
+\[X^{-1} = (2a_0 - X)/(a^2_0 - a^2_1 - a^2_2 + a^2_3) = 0\]
+
+which provides a general solution to the inverse in this algebra.
+
+\[c^{-1} = (2a_0 - c)/(a^2_0 - a^2_1 - a^2_2 + a^2_3) = 0\]
+
+\subsection{Example 2: Clifford (3)}
+
+A set of basis matrices for Clifford (3) as given by Abalmowicz and
+deduced are
+
+\[
+\begin{array}{cc}
+E_0 =
+\left(
+\begin{array}{cc}
+1&0\\
+0&1
+\end{array}\right) &
+E_1 =
+\left(
+\begin{array}{cc}
+1&0\\
+0&-1
+\end{array}\right) \\
+E_2 =
+\left(
+\begin{array}{cc}
+0&1\\
+1&0
+\end{array}\right) &
+E_3 =
+\left(
+\begin{array}{cc}
+0&-j\\
+j&0
+\end{array}\right) \\
+E_1E_2 =
+\left(
+\begin{array}{cc}
+0&1\\
+-1&0
+\end{array}\right) &
+E_1E_3 =
+\left(
+\begin{array}{cc}
+0&-j\\
+-j&0
+\end{array}\right) \\
+E_2E_3 =
+\left(
+\begin{array}{cc}
+j&0\\
+0&-j
+\end{array}\right) &
+E_1E_2E_3 =
+\left(
+\begin{array}{cc}
+j&0\\
+0&j
+\end{array}\right) \\
+\end{array}
+\]
+
+for the idempotent 
+
+\[f = \frac{(1 + e_1)}{2}, {\rm\ where\ } j^2 = -1.\]
+
+The general member of the algebra
+
+\[c_3 = a_0 +a_1e_1 + a_2e_2 + a_3e_3 + 
+a_{12}e_1e_2 + a_{13}e_1e_3 + a_{23}e_2e_3 + a_{123}e_1e_2e_3\]
+
+has the matrix representation
+
+\[
+\begin{array}{rcl}
+A_3&=&a_0E_0 + a_1E_1 + a_2E_2 +a_3E_3 + a_{12}E_1E_2\\
+&& +a_{13}E_1E_3 + a_{23}E_2E_3 + a_{123}E_1E_2E_3\\
+&&\\
+&=&\left(
+\begin{array}{cc}
+a_0 + a_1 + ja_{23} + ja_{123}& a_2 -ja_3 +a_{12} -ja_{13}\\
+a_2 + ja_3- a_{12}- ja_{13}& a_0- a_1- ja_{23} + ja_{123}
+\end{array}
+\right)
+\end{array}
+\]
+
+This has the characteristic polynomial
+
+\[
+\begin{array}{rl}
+&a^2_0-a^2_1-a^2_2-a^2_3+a^2_{12}+a^2_{13}+a^2_{23}-a^2_{123}\\
+&\\
++&2j(a_0a_{123}-a_1a_{23}-a_{12}a_3+a_{13}a_2)\\
+&\\
+-&2(a_0+ja_{123})X + X^2=0
+\end{array}
+\]
+
+and the expression for the inverse is
+
+\[
+\begin{array}{rcl}
+X^{-1}&=&(2a_0 + 2ja_{123} -X) /\\
+&&(a^2_0-a^2_1-a^2_2-a^2_3+a^2_{12}+a^2_{13}+a^2_{23}-a^2_{123}\\
+&&+2j(a_0a_{123}-a_1a_{23}-a_{12}a_3+a_{13}a_2))
+\end{array}
+\]
+
+Complex terms arise in two cases,
+
+\[a_{123} \ne 0\]
+
+and
+
+\[(a_0a_{123}-a_1a_{23}-a_{12}a_3+a_{13}a_2) \ne 0\]
+
+Two simple cases have real minumum polynomials:
+
+Zero and first grade terms only:
+
+\[
+\begin{array}{rcl}
+A_1&=&a_0E_0 + a_1E_1 + a_2E_2 + a_3E_3\\
+&=&\left(
+\begin{array}{cc}
+a_0+a_1 & a_2-ja_3\\
+a_2+ja_3 & a_0-a_1
+\end{array}
+\right)
+\end{array}
+\]
+
+which has the minimum polynomial
+
+\[a^2_0-a^2_1-a^2_2-a^2_3-2a_0X+X^2=0\]
+
+which gives
+
+\[X^{-1} = (2a_0- X) / (a^2_0- a^2_1- a^2_2 - a^2_3)\]
+
+Zero and second grade terms only (ie. the even subspace).
+
+\[
+\begin{array}{rcl}
+A_2&=&a_0E_0 + a_{12}E_1E_2 + a_{13}E_1E_3 + a_{23}E_2E_3\\
+&&\left(
+\begin{array}{cc}
+a_0+ja_{23}     & a_{12}-ja_{13}\\
+-a_{12}-ja_{13} & a_0-ja_{23}
+\end{array}
+\right)
+\end{array}
+\]
+
+which has minimum polynomial
+
+\[a^2_0+a^2_{23}+a^2_{12}+a^2_{13}-2a_0X+X^2 = 0\]
+
+giving
+
+\[X^{-1} = (2a_0- X) /(a^2_0 + a^2_{23} + a^2_{12} + a^2_{13})\]
+
+This provides a general solution for the inverse together with two
+simple cases of wide usefulness.
+
+\subsection{Example 3: Clifford (2,2)}
+
+The following basis matrices are given by Ablamowicz\cite{41}
+
+\[
+\begin{array}{cc}
+E_1=\left(
+\begin{array}{cccc}
+0 & 1 & 0 & 0\\
+1 & 0 & 0 & 0\\
+0 & 0 & 0 & 1\\
+0 & 0 & 1 & 0
+\end{array}
+\right)&
+E_2=\left(
+\begin{array}{cccc}
+0 & 0 & 1 & 0\\
+0 & 0 & 0 & -1\\
+1 & 0 & 0 & 0\\
+0 & -1 & 0 & 0
+\end{array}
+\right)\\
+E_3=\left(
+\begin{array}{cccc}
+0 & -1 & 0 & 0\\
+1 & 0 & 0 & 0\\
+0 & 0 & 0 & -1\\
+0 & 0 & 1 & 0
+\end{array}
+\right)&
+E_4=\left(
+\begin{array}{cccc}
+0 & 0 & -1 & 0\\
+0 & 0 & 0 & 1\\
+1 & 0 & 0 & 0\\
+0 & -1 & 0 & 0
+\end{array}
+\right)
+\end{array}
+\]
+
+for the idempotent 
+\[f = \frac{(1 +e_1e_3) (1+ e_1e_3)}{4}.\]
+
+ Note that this implies that the order of the basis members is such
+that $e_1$ and $e_2$ have square $+1$ and $e_3$ and $e_4$ have square
+$-1$. Other orderings are used by other authors. The remaining basis
+matrices can be deduced to be as follows.
+
+Second Grade members
+
+\[
+\begin{array}{cc}
+E_1E_2 = \left(
+\begin{array}{cccc}
+0 & 0 & 0 & -1\\
+0 & 0 & 1 & 0\\
+0 & -1 & 0 & 0\\
+1 & 0 & 0 & 0
+\end{array}\right)&
+E_1E_3 = \left(
+\begin{array}{cccc}
+1 & 0 & 0 & 0\\
+0 & -1 & 0 & 0\\
+0 & 0 & 1 & 0\\
+0 & 0 & 0 & -1
+\end{array}\right)\\
+E_1E_4 = \left(
+\begin{array}{cccc}
+0 & 0 & 0 & 1\\
+0 & 0 & -1 & 0\\
+0 & -1 & 0 & 0\\
+1 & 0 & 0 & 0
+\end{array}\right)&
+E_2E_3 = \left(
+\begin{array}{cccc}
+0 & 0 & 0 & -1\\
+0 & 0 & -1 & 0\\
+0 & -1 & 0 & 0\\
+-1 & 0 & 0 & 0
+\end{array}\right)\\
+E_2E_4 = \left(
+\begin{array}{cccc}
+1 & 0 & 0 & 0\\
+0 & 1 & 0 & 0\\
+0 & 0 & -1 & 0\\
+0 & 0 & 0 & -1
+\end{array}\right)&
+E_3E_4 = \left(
+\begin{array}{cccc}
+0 & 0 & 0 & -1\\
+0 & 0 & -1 & 0\\
+0 & 1 & 0 & 0\\
+1 & 0 & 0 & 0
+\end{array}\right)\\
+\end{array}
+\]
+
+Third grade members
+
+\[
+\begin{array}{cc}
+E_1E_2E_3 = \left(
+\begin{array}{cccc}
+0 & 0 & -1 & 0\\
+0 & 0 & 0 & -1\\
+-1 & 0 & 0 & 0\\
+0 & -1 & 0 & 0
+\end{array}\right)&
+E_1E_2E_4 = \left(
+\begin{array}{cccc}
+0 & 1 & 0 & 0\\
+1 & 0 & 0 & 0\\
+0 & 0 & 0 & -1\\
+0 & 0 & -1 & 0
+\end{array}\right)\\
+E_1E_3E_4 = \left(
+\begin{array}{cccc}
+0 & 0 & -1 & 0\\
+0 & 0 & 0 & -1\\
+1 & 0 & 0 & 0\\
+0 & 1 & 0 & 0
+\end{array}\right)&
+E_2E_3E_4 = \left(
+\begin{array}{cccc}
+0 & 1 & 0 & 0\\
+-1 & 0 & 0 & 0\\
+0 & 0 & 0 & -1\\
+0 & 0 & 1 & 0
+\end{array}\right)
+\end{array}
+\]
+
+Fourth grade member
+
+\[
+E_1E_2E_3E_4 = \left(
+\begin{array}{cccc}
+-1 & 0 & 0 & 0\\
+0 & 1 & 0 & 0\\
+0 & 0 & 1 & 0\\
+0 & 0 & 0 & -1
+\end{array}
+\right)
+\]
+
+Zero grade member (identity)
+
+\[
+E_0 = \left(
+\begin{array}{cccc}
+1 & 0 & 0 & 0\\
+0 & 1 & 0 & 0\\
+0 & 0 & 1 & 0\\
+0 & 0 & 0 & 1
+\end{array}
+\right)
+\]
+
+The general member of the Clifford (2,2) algebra can be written as follows.
+
+\[\begin{array}{rcl}
+c_{22}&=& a_0 + a_1e_1 + a_2e_2 + a_3e_3 + a_4e_4 +\\
+&&a_{12}e_1e_2+a_{13}e_1e_3+a_{14}e_1e_4+a_{23}e_2e_3+a_{24}e_2e_4+
+a_{34}e_3e_4\\
+&&+ a_{123}e_1e_2e_3 +a_{124}e_1e_2e_4 +a_{134}e_1e_3e_4 + 
+a_{234}e_2e_3e_4 + a_{1234}e_1e_2e_3e_4
+\end{array}
+\]
+
+This has the following matrix representation.
+
+\[
+\left(
+\begin{array}{cccc}
+a_0+a_{13}+    & a_1-a_3+        & a_2-a_4-        & -a_{12}+a_{14}-\\
+a_{24}-a_{1234}& a_{124}+a_{234} & a_{123}-a_{134} & a_{23}-a_{34}\\
+&&&\\
+a_1+a_3+        & a_0-a_{13}+     & a_{12}-a_{14}- & -a_2+a_4-\\
+a_{124}-a_{234} & a_{24}+a_{1234} & a_{23}-a_{34}  & a_{123}-a_{134}\\
+&&&\\
+a_2+a_4-        & -a_{12}-a_{14}- & a_0+a_{13}-     & a_1-a_3-\\
+a_{123}+a_{134} & a_{23}+a_{34}   & a_{24}+a_{1234} & a_{124}-a_{234}\\
+&&&\\
+a_{12}+a_{14}- & -a_2-a_4-       & a_1+a_3-        & a_0-a_{13}-\\
+a_{23}+a_{34}  & a_{123}+a_{134} & a_{124}+a_{234} & a_{24}-a_{1234}
+\end{array}
+\right)
+\]
+
+In this case it is possible to generate the characteristic equation
+using computer algebra. However, it is too complex to be of practical
+use. Instead here are numerical examples of the use of the method to
+calculate the inverse. For the case where
+
+\[n1 = 1+ e_1 + e_2 + e_3 + e_4\]
+
+then the matrix representation is
+
+\[N_1 = E_0 +E_1 + E_2 + E_3 + E_4 = 
+\left(
+\begin{array}{cccc}
+1 & 0 & 0 & 0\\
+2 & 1 & 0 & 0\\
+2 & 0 & 1 & 0\\
+0 & -2 & 2 & 1
+\end{array}
+\right)
+\]
+
+This has the minimum polynomial
+
+\[X^2 - 2X + 1 = 0\]
+
+so that
+
+\[X^{-1} = 2- X\]
+
+and
+
+\[n^{-1}_1= 2 - n_1 = 1 - e_1 - e_2- e_3- e_4\]
+
+For
+
+\[n_2 = 1+ e_1 + e_2 + e_3 + e_4 +e_1e_2\]
+
+the matrix representation is
+
+\[N_2 = I + E_1 + E_2 + E_3 +E_4 + E_1E_2 = 
+\left(
+\begin{array}{cccc}
+1 & 0 & 0 & -1\\
+2 & 1 & 1 & 0\\
+2 & -1 & 1 & 0\\
+1 & -2 & 2 & 1
+\end{array}
+\right)
+\]
+
+This has the minimum polynomial
+
+\[X^4 - 4X^3 + 8X^2 - 8X - 4 = 0\]
+
+so that
+
+\[X^{-1} = \frac{X^3 - 4X^2 + 8X - 8}{4}\]
+
+and
+
+\[n^{-1}_2 = \frac{n^3_2- 4n^2_2 + 8n_2 - 8}{4}\]
+
+This expression can be evaluated easily using a computer algebra
+system for Clifford algebra such as described in Fletcher\cite{40}. 
+The result is
+
+\[
+\begin{array}{rcl}
+n^{-1}_2 &=& -0.5 + 0.5e_1 + 0.5e_2 - 0.5e_1e_2 - 0.5e_1e_3\\
+&& - 0.5e_1e_4 + 0.5e_2e_3 + 0.5e_2e_4 - 0.5e_1e_2e_3 - 0.5e_1e_2e_4
+\end{array}
+\]
+
+
+Note that in some cases the inverse is linear in the original Clifford
+number, and in others it is nonlinear.
+
+\subsection{Conclusion}
+
+The paper has demonstrated a method for the calculation of inverses of
+Clifford numbers by means of the matrix representation of the
+corresponding Clifford algebra.  The method depends upon the
+calculation of the basis matrices for the algebra.  This can be done
+from an idempotent for the algebra if the matrices are not already
+available.  The method provides an easy check on the existence of the
+inverse.  For simple systems a general algebraic solution can be found
+and for more complex systems the algebra of the inverse can be
+generated and evaluated numerically for a particular example, given a
+system of computer algebra for Clifford algebra.
 
 \chapter{Groebner Basis}
 Groebner Basis
@@ -7708,6 +8462,17 @@ Addison-Wesley Publishing Company, Inc.,
 "On Quaternions and Octonions", A.K Peters, Natick, MA. (2003)
 ISBN 1-56881-134-9
 \bibitem{38} http://mathworld.wolfram.com/Quaternion.html
+\bibitem{39} Fletcher, John P. ``Clifford Numbers and their inverses
+calculated using the matrix representation.'' Chemical Engineering and
+Applied Chemistry, School of Engineering and Applied Science, Aston
+University, Aston Triangle, Birmingham B4 7 ET, U. K. 
+\verb|http://www.ceac.aston.ac.uk/research/staff/jpf/papers/paper24/index.php|
+\bibitem{40} Fletcher, John P. ``Symbolic processing of Clifford
+Numbers in C++'', Paper 25, AGACSE 2001.
+\bibitem{41} Ablamowicz Rafal, ``Spinor Representations of Clifford
+Algebras: A Symbolic Approach'', Computer Physics Communications
+Vol. 115, No. 2-3, December 11, 1998, pages 510-535.
+
 \end{thebibliography}
 \end{document}
 
diff --git a/books/bookvol5.pamphlet b/books/bookvol5.pamphlet
index bdae2bc..04c08f6 100644
--- a/books/bookvol5.pamphlet
+++ b/books/bookvol5.pamphlet
@@ -356,8 +356,9 @@ of effort. We would like to acknowledge and thank the following people:
 "Brian Dupee            Dominique Duval"
 "Robert Edwards         Heow Eide-Goodman      Lars Erickson"
 "Richard Fateman        Bertfried Fauser       Stuart Feldman"
-"Brian Ford             Albrecht Fortenbacher  George Frances"
-"Constantine Frangos    Timothy Freeman        Korrinn Fu"
+"John Fletcher          Brian Ford             Albrecht Fortenbacher"
+"George Frances         Constantine Frangos    Timothy Freeman"
+"Korrinn Fu"
 "Marc Gaetano           Rudiger Gebauer        Kathy Gerber"
 "Patricia Gianni        Samantha Goldrich      Holger Gollan"
 "Teresa Gomez-Diaz      Laureano Gonzalez-Vega Stephen Gortler"
diff --git a/changelog b/changelog
index 9f2b94b..3b23599 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,8 @@
+20100216 tpd src/axiom-website/patches.html 20100216.02.jpf.patch
+20100216 jpf books/bookvol10.1 add Clifford chapter
+20100216 jpf books/bookvol5 add John Fletcher to credits
+20100216 jpf readme added to John Fletcher credits
+20100216 jpf John P. Fletcher <J.P.Fletcher@aston.ac.uk>
 20100216 tpd src/axiom-website/patches.html 20100216.01.rhx.patch
 20100216 tpd src/input/cachedf.input fix tests for )set break quit
 20100216 tpd src/input/unittest2.input fix tests for )set break quit
diff --git a/readme b/readme
index bf76111..c9716cd 100644
--- a/readme
+++ b/readme
@@ -210,8 +210,9 @@ at the axiom command prompt will prettyprint the list.
 "Brian Dupee            Dominique Duval"
 "Robert Edwards         Heow Eide-Goodman      Lars Erickson"
 "Richard Fateman        Bertfried Fauser       Stuart Feldman"
-"Brian Ford             Albrecht Fortenbacher  George Frances"
-"Constantine Frangos    Timothy Freeman        Korrinn Fu"
+"John Fletcher          Brian Ford             Albrecht Fortenbacher"
+"George Frances         Constantine Frangos    Timothy Freeman"
+"Korrinn Fu"
 "Marc Gaetano           Rudiger Gebauer        Kathy Gerber"
 "Patricia Gianni        Samantha Goldrich      Holger Gollan"
 "Teresa Gomez-Diaz      Laureano Gonzalez-Vega Stephen Gortler"
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index f4354cc..169650b 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -2461,5 +2461,7 @@ books/bookvol5 treeshake cparse, ptrees<br/>
 books/bookvol5 treeshake cparse, ptrees, ptrop vmlisp<br/>
 <a href="patches/20100216.01.rhx.patch">20100216.01.rhx.patch</a>
 books/bookvol5 add )set break quit<br/>
+<a href="patches/20100216.02.jpf.patch">20100216.02.jpf.patch</a>
+books/bookvol10.1 add Clifford chapter, per John Fletcher<br/>
  </body>
 </html>
